%**********
% ctrst.m
%
% MATLAB M-File for computation of the thermal contrast
% from a sequence of images ( of unsigned characters type)
% located in the working directory. Return a floating
% point contrast image.
%
% Parameter TYPE allows to compute the various contrast
% discussed depending of provided value (Section 5.4):
% (1) absolute contrast, (2) running contrast,
% (3) normalized contrast, (4) standard contrast.
% Defect-free zone within the image is defined with
% rectangle having respectively upper left and bottom-right
% coordinates (x1,y1) and (x2,y2). The matrice mat is the
% termal image for which the contrast is being computed and
% mat0 is the image at time tm or t0. For TYPE 1 and 2,
% mat0 is not used and can be any matrice.
%
% Example of use:
%  mat_ctr=ctrst(4,2,2,50,10,mat,mat0);
%
% Date : 26.05.2000
%
% Last modification: 31.05.2000
%
%**********

function  mat1 = ctrst(TYPE,x1,y1,x2,y2,mat,mat0)


% ***** Defect-free area
Ts=mean(mean(mat(x1:x2,y1:y2)));	% mean value of the defect-free area


% ***** Contrast computation

switch TYPE
        
case 1,
% ***** Absolute contrast

	% Ca(t)=deltaT(t)=Tdef(t)-Ts(t)
	mat1 = mat - Ts;

	% ***** Display the image
	colormap(gray);
	imagesc(mat1);
	colorbar;


case 2,
% ***** Running contrast

	% Cr(t)=Ca(t)/Ts(t)=deltaT(t)/Ts(t)
	mat1 = (mat - Ts) / Ts;

	% ***** Display the image
	colormap(gray);
	imagesc(mat1);
	colorbar;


case 3,
% ***** Normalized contrast

	% ***** Defect-free area of image at tm
	Tsm=mean(mean(mat0(x1:x2,y1:y2)));	% mean value of the defect-free area

	% Cn(t)=Ti(t)/Ti(tm)-Ts(t)/Ts(tm), Ti=Tdef
	mat1 = mat./mat0 - Ts/Tsm;

	% ***** Display the image
	colormap(gray);
	imagesc(mat1);
	colorbar;


case 4,
% ***** Standard contrast

	% ***** Defect-free area of image at tm
	Ts0=mean(mean(mat0(x1:x2,y1:y2)));	% mean value of the defect-free area

	% Cs(t)=(Ti(t)-Ti(t0))/(Ts(t)-Ts(t0))
	if Ts-Ts0~=0,
		mat1 = (mat-mat0) / (Ts-Ts0);
	else
		disp('error: division by zero')
	end

	% ***** Display the image
	colormap(gray);
	imagesc(mat1);
	colorbar;


% ***** wrong type number
otherwise,
   disp('Wrong type')

end
