%**********
% enh_pro.m
%
% MATLAB M-File for image enhancement with parameters k1
% and k2. Return the enhanced image, based on eq.(5.20).
% (eq.(5.19) can be obtained by choosing k2=1). Images
% are of unsigned characters type.
% Adjustable parameter is:
%  Size:	local mean is calculated over Size pixels wide
% 		window centered in (i,j)
%
% Example of use:
%  mat1=enh_pro(mat,5,0.5);
%
% Date : 18.05.2000
%
% Last modification: 02.06.2000
%
%**********

function  mat1=enh_pro(mat,k1,k2)


% ***** Size of matrice and initialization
[mrow, mcol]=size(mat);
mat1=zeros(mrow,mcol);
Size=3;
fsize=floor(Size/2);	% round towards lowest nearest integer


% ***** Image enhancement
for i= 1:mrow,
   for j=1:mcol,


% ***** Number of elements around (i,j)

% ***** Left side (with (i,j))
if j>fsize	% general case
	l=fsize+1;
else
	l=j;	% sides and corners case
end

% ***** Right side
if (mcol-j)>fsize	% general case
	r=fsize;
else
	r=mcol-j;	% sides and corners case
end

% ***** Up side (with (i,j))
if i>fsize	% general case
	u=fsize+1;
else
	u=i;	% sides and corners case
end

% ***** Down side
if (mrow-i)>fsize	% general case
	d=fsize;
else
	d=mrow-i;	% sides and corners case
end


% ***** Computation of the local mean in kernel of interest
ker(1:u+d,1:l+r)=mat(i-u+1:i+d,j-l+1:j+r);
locm=mean(ker(:));	% average of ker


% ***** Attribution of new value to (i,j)
mat1(i,j)=(k2-k1)*locm + k1*mat(i,j);

	end
end

%mat1=mat_fl_to_uc(mat1);

% ***** Display the image
colormap(gray);
imagesc(mat1);
colorbar;
