%**********
% median_filter.m
%
% MATLAB M-File for noise suppresion through
% median filtering. Return the processed image.
% Images are of unsigned characters type.
% Parameter 'size' defines the size of the kernel
% of interest and must be a odd number. If size
% is even, the fonction uses size plus one.
%
% Example of use:
%  mat1=median_filter(mat,3);
%
% Date : 17.05.2000
%
% Last modification: 02.06.2000
%
%**********

function mat1 = median_filter(mat,size)


% ***** Verification of variable size
if mod(size,2)~=1,	% remainder after division by two
	disp('warning: size should be odd');	% display message
	size=size+1;
end


% ***** Size of matrix and initialization of mat1
[mrow, mcol]=size(mat);
mat1=zeros(mrow,mcol);

fsize=floor(size/2);	% round towards lowest nearest integer


% ***** Noise suppresion through median filtering
for i=1:mrow,
	for j=1:mcol,


% ***** Number of elements around (i,j)

% ***** Left side (with (i,j))
if j>fsize	% general case
	l=fsize+1;
else
	l=j;	% sides and corners case
end

% ***** Right side
if (mcol-j)>fsize	% general case
	r=fsize;
else
	r=mcol-j;	% sides and corners case
end

% ***** Up side (with (i,j))
if i>fsize	% general case
	u=fsize+1;
else
	u=i;	% sides and corners case
end

% ***** Down side
if (mrow-i)>fsize	% general case
	d=fsize;
else
	d=mrow-i;	% sides and corners case
end


% ***** Kernel of interest
ker=mat(i-u+1:i+d,j-l+1:j+r);


% ***** Attribution of new value to (i,j)
mat1(i,j)=median(ker(:));	% find the median in kernel

	end
end


%mat1=mat_fl_to_uc(mat1);


% ***** Display the image
colormap(gray);
imagesc(mat1);
colorbar;
