%**********
% moment.m
%
% Return the moment image in float from the image
% sequence present on disk in directory dir.
% Computation proceeds in the time period ta to
% tb (coded in the name of the file having the
% prefix pre and extension ext). incre is the
% time increment between images. option parameters
% are: 1- add all images, 2- average of all images,
% 3- add all images and convert to unsigned char.
%
% A header is account for.
% Adjustable parameters are:
%	Header: number of bytes before the image
%	MaxRow: number of pixels per row
%	Maxcol: number of pixels per row
%
% Example of use:
%  mat=moment('G:\images\','d_','uc',200,2000,10,2);
%
% Date : 31.05.2000
%
% Last modification: 01.06.2000
%
%**********

function mat = moment(dir,pre,ext,ta,tb,incre,option)


% ***** Initialization of mat
Header = 105; Maxcol = 105; Maxrow = 68;
mat=zeros(Maxrow,Maxcol);

numfiles=0;


% ***** Summation of images eq.(6.3) from time ta to tb
for t=ta:incre:tb

	t=num2str(t);	% convert number t to a character string

	% ***** Concatenate the name and location of the file
	% into a single string
	file=strcat(dir,pre,t,'.',ext);

	% ***** As in chapter 5 function read_uc.m
	fid = fopen(file,'r');

	if fid==-1,
		error=strcat('Cannot open: ',file);
		disp(error);
	else
		fread(fid,Header,'uchar');
		out1 = fread(fid,[Maxcol,Maxrow],'uchar');
		fclose(fid);
		out=out1';	% correct for Matlab display (transpose)
		numfiles=numfiles+1;


	% ***** Summation of images
	mat=mat+out;

	end

end

if option==2
	mat=mat./numfiles;
elseif option==3
	mat=mat_fl_to_uc(mat);
end


% ***** Display the image
colormap(gray);
imagesc(mat);
colorbar;
