%**********
% timezones.m
%
% Matlab M-file to compute a logarithmic time scale.
%
% NM is the maximum of images. q is the image
% acquisition + temporaray storage rate. N is the
% number of zones wanted. to is the starting of
% acquisition and tf is the end of the experiment.
% Parameter p is specifies for witch case the time
% zones are computed:
% 	1: dijoint case
% 	all other values: continuous case
%
% Example of use:
%  out=timezones(284,0.27,10,1,100,1)
%
% Date : 06.06.2000
%
% Last modification: 06.06.2000
%
%**********

function out = timezones2(NM,q,N,to,tf,p)



if p==1	% disjoint case

	% ***** Zones of temporal scale
	mu=(tf/to)^(1/(N-1))	% eq.(10.33)
	ti=to*mu.^(0:N-1);	% eq.(10.33)


	% ***** Lambda computation, eq.(10.35) and (10.36)
	factor=(to/q)*((1-mu^N)/(1-mu)+N);

	i=1
	lambda=factor/(factor-NM)
	NMest=sum(ceil((ti./q).*(1-1/lambda)+1))

	while (NMest > NM) & (i< 50)

		lambda=factor/(factor-NMest);
		NMest=sum(floor((ti./q).*(1-1/lambda)+1));
		i=i+1;

	end

	i
	lambda
	NMest


	% ***** Low borders of time zones
	ti_=ti/lambda;	% zone i spans from ti_ to ti, eq.(10.34)



else	% continuous case

	mu=to/(to-q)	% eq.(10.46)

	tf=min(tf,to+NM*q)	% eq.(10.47)

	N=round(1+log(tf/to)/log(mu))	% eq.(10.48)

	% zone i spans from ti_ to ti,
	ti=to*mu.^(0:N-1);	% eq.(10.33)
	ti_=ti/mu;	 % eq.(10.34) and (10.42)

end



zone=0:N-1;

out=[zone' ti_' ti'];
